@@ -1,7 +1,7 @@
 """
 Type annotations for es service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/)
 
 Usage::
 
@@ -119,7 +119,7 @@ class Exceptions:
 class ElasticsearchServiceClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/)
     """
 
     meta: ClientMeta
@@ -130,7 +130,7 @@ class ElasticsearchServiceClient(BaseClient):
         ElasticsearchServiceClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#exceptions)
         """
 
     def accept_inbound_cross_cluster_search_connection(
@@ -141,7 +141,7 @@ class ElasticsearchServiceClient(BaseClient):
         connection request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#accept_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#accept_inbound_cross_cluster_search_connection)
         """
 
     def add_tags(self, *, ARN: str, TagList: Sequence["TagTypeDef"]) -> None:
@@ -149,7 +149,7 @@ class ElasticsearchServiceClient(BaseClient):
         Attaches tags to an existing Elasticsearch domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.add_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#add_tags)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#add_tags)
         """
 
     def associate_package(
@@ -159,7 +159,7 @@ class ElasticsearchServiceClient(BaseClient):
         Associates a package with an Amazon ES domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.associate_package)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#associate_package)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#associate_package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -167,7 +167,7 @@ class ElasticsearchServiceClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#can_paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
@@ -177,7 +177,7 @@ class ElasticsearchServiceClient(BaseClient):
         Cancels a scheduled service software update for an Amazon ES domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#cancel_elasticsearch_service_software_update)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#cancel_elasticsearch_service_software_update)
         """
 
     def create_elasticsearch_domain(
@@ -204,7 +204,7 @@ class ElasticsearchServiceClient(BaseClient):
         Creates a new Elasticsearch domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_elasticsearch_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#create_elasticsearch_domain)
         """
 
     def create_outbound_cross_cluster_search_connection(
@@ -219,7 +219,7 @@ class ElasticsearchServiceClient(BaseClient):
         destination domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_outbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#create_outbound_cross_cluster_search_connection)
         """
 
     def create_package(
@@ -234,7 +234,7 @@ class ElasticsearchServiceClient(BaseClient):
         Create a package for use with Amazon ES domains.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.create_package)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#create_package)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#create_package)
         """
 
     def delete_elasticsearch_domain(
@@ -244,7 +244,7 @@ class ElasticsearchServiceClient(BaseClient):
         Permanently deletes the specified Elasticsearch domain and all of its data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_elasticsearch_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#delete_elasticsearch_domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
@@ -253,7 +253,7 @@ class ElasticsearchServiceClient(BaseClient):
         maintain VPC domains.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_elasticsearch_service_role)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#delete_elasticsearch_service_role)
         """
 
     def delete_inbound_cross_cluster_search_connection(
@@ -264,7 +264,7 @@ class ElasticsearchServiceClient(BaseClient):
         search connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#delete_inbound_cross_cluster_search_connection)
         """
 
     def delete_outbound_cross_cluster_search_connection(
@@ -275,7 +275,7 @@ class ElasticsearchServiceClient(BaseClient):
         search connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_outbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#delete_outbound_cross_cluster_search_connection)
         """
 
     def delete_package(self, *, PackageID: str) -> DeletePackageResponseTypeDef:
@@ -283,7 +283,7 @@ class ElasticsearchServiceClient(BaseClient):
         Delete the package.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.delete_package)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#delete_package)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#delete_package)
         """
 
     def describe_domain_auto_tunes(
@@ -294,7 +294,7 @@ class ElasticsearchServiceClient(BaseClient):
         as Auto-Tune action type, description, severity, and scheduled date.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_domain_auto_tunes)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_domain_auto_tunes)
         """
 
     def describe_domain_change_progress(
@@ -305,7 +305,7 @@ class ElasticsearchServiceClient(BaseClient):
         domain, including a change ID, status, and progress stages.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_domain_change_progress)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_domain_change_progress)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_domain_change_progress)
         """
 
     def describe_elasticsearch_domain(
@@ -316,7 +316,7 @@ class ElasticsearchServiceClient(BaseClient):
         domain, including the domain ID, domain endpoint, and domain ARN.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_elasticsearch_domain)
         """
 
     def describe_elasticsearch_domain_config(
@@ -328,7 +328,7 @@ class ElasticsearchServiceClient(BaseClient):
         cluster options.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domain_config)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_elasticsearch_domain_config)
         """
 
     def describe_elasticsearch_domains(
@@ -339,7 +339,7 @@ class ElasticsearchServiceClient(BaseClient):
         domains, including the domain ID, domain endpoint, and domain ARN.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_domains)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_elasticsearch_domains)
         """
 
     def describe_elasticsearch_instance_type_limits(
@@ -353,7 +353,7 @@ class ElasticsearchServiceClient(BaseClient):
         Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_elasticsearch_instance_type_limits)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_elasticsearch_instance_type_limits)
         """
 
     def describe_inbound_cross_cluster_search_connections(
@@ -367,7 +367,7 @@ class ElasticsearchServiceClient(BaseClient):
         Lists all the inbound cross-cluster search connections for a destination domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_inbound_cross_cluster_search_connections)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_inbound_cross_cluster_search_connections)
         """
 
     def describe_outbound_cross_cluster_search_connections(
@@ -381,7 +381,7 @@ class ElasticsearchServiceClient(BaseClient):
         Lists all the outbound cross-cluster search connections for a source domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_outbound_cross_cluster_search_connections)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_outbound_cross_cluster_search_connections)
         """
 
     def describe_packages(
@@ -395,7 +395,7 @@ class ElasticsearchServiceClient(BaseClient):
         Describes all packages available to Amazon ES.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_packages)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_packages)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_packages)
         """
 
     def describe_reserved_elasticsearch_instance_offerings(
@@ -409,7 +409,7 @@ class ElasticsearchServiceClient(BaseClient):
         Lists available reserved Elasticsearch instance offerings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_reserved_elasticsearch_instance_offerings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_reserved_elasticsearch_instance_offerings)
         """
 
     def describe_reserved_elasticsearch_instances(
@@ -423,7 +423,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns information about reserved Elasticsearch instances for this account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#describe_reserved_elasticsearch_instances)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#describe_reserved_elasticsearch_instances)
         """
 
     def dissociate_package(
@@ -433,7 +433,7 @@ class ElasticsearchServiceClient(BaseClient):
         Dissociates a package from the Amazon ES domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#dissociate_package)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#dissociate_package)
         """
 
     def generate_presigned_url(
@@ -447,7 +447,7 @@ class ElasticsearchServiceClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#generate_presigned_url)
         """
 
     def get_compatible_elasticsearch_versions(
@@ -457,7 +457,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns a list of upgrade compatible Elastisearch versions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_compatible_elasticsearch_versions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_compatible_elasticsearch_versions)
         """
 
     def get_package_version_history(
@@ -468,7 +468,7 @@ class ElasticsearchServiceClient(BaseClient):
         commit message.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_package_version_history)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_package_version_history)
         """
 
     def get_upgrade_history(
@@ -479,7 +479,7 @@ class ElasticsearchServiceClient(BaseClient):
         the domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_upgrade_history)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_upgrade_history)
         """
 
     def get_upgrade_status(self, *, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
@@ -488,7 +488,7 @@ class ElasticsearchServiceClient(BaseClient):
         that was performed on the domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_upgrade_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_upgrade_status)
         """
 
     def list_domain_names(
@@ -499,7 +499,7 @@ class ElasticsearchServiceClient(BaseClient):
         account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_domain_names)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#list_domain_names)
         """
 
     def list_domains_for_package(
@@ -509,7 +509,7 @@ class ElasticsearchServiceClient(BaseClient):
         Lists all Amazon ES domains associated with the package.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_domains_for_package)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#list_domains_for_package)
         """
 
     def list_elasticsearch_instance_types(
@@ -526,7 +526,7 @@ class ElasticsearchServiceClient(BaseClient):
         Documentation](https://docs.aws.amazon.com/goto/WebAPI/es-2015-01-01/ListElasticsearchInstanceTypes).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_elasticsearch_instance_types)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#list_elasticsearch_instance_types)
         """
 
     def list_elasticsearch_versions(
@@ -537,7 +537,7 @@ class ElasticsearchServiceClient(BaseClient):
         Documentation](https://docs.aws.amazon.com/goto/WebAPI/es-2015-01-01/ListElasticsearchVersions).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_elasticsearch_versions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#list_elasticsearch_versions)
         """
 
     def list_packages_for_domain(
@@ -547,7 +547,7 @@ class ElasticsearchServiceClient(BaseClient):
         Lists all packages associated with the Amazon ES domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_packages_for_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#list_packages_for_domain)
         """
 
     def list_tags(self, *, ARN: str) -> ListTagsResponseTypeDef:
@@ -555,7 +555,7 @@ class ElasticsearchServiceClient(BaseClient):
         Returns all tags for the given Elasticsearch domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.list_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#list_tags)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#list_tags)
         """
 
     def purchase_reserved_elasticsearch_instance_offering(
@@ -569,7 +569,7 @@ class ElasticsearchServiceClient(BaseClient):
         Allows you to purchase reserved Elasticsearch instances.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#purchase_reserved_elasticsearch_instance_offering)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#purchase_reserved_elasticsearch_instance_offering)
         """
 
     def reject_inbound_cross_cluster_search_connection(
@@ -580,7 +580,7 @@ class ElasticsearchServiceClient(BaseClient):
         connection request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#reject_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#reject_inbound_cross_cluster_search_connection)
         """
 
     def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> None:
@@ -588,7 +588,7 @@ class ElasticsearchServiceClient(BaseClient):
         Removes the specified set of tags from the specified Elasticsearch domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.remove_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#remove_tags)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#remove_tags)
         """
 
     def start_elasticsearch_service_software_update(
@@ -598,7 +598,7 @@ class ElasticsearchServiceClient(BaseClient):
         Schedules a service software update for an Amazon ES domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#start_elasticsearch_service_software_update)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#start_elasticsearch_service_software_update)
         """
 
     def update_elasticsearch_domain_config(
@@ -625,7 +625,7 @@ class ElasticsearchServiceClient(BaseClient):
         setting as setting the instance type and the number of instances.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#update_elasticsearch_domain_config)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#update_elasticsearch_domain_config)
         """
 
     def update_package(
@@ -640,7 +640,7 @@ class ElasticsearchServiceClient(BaseClient):
         Updates a package for use with Amazon ES domains.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.update_package)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#update_package)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#update_package)
         """
 
     def upgrade_elasticsearch_domain(
@@ -651,7 +651,7 @@ class ElasticsearchServiceClient(BaseClient):
         to a compatible Elasticsearch version.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#upgrade_elasticsearch_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#upgrade_elasticsearch_domain)
         """
 
     @overload
@@ -660,7 +660,7 @@ class ElasticsearchServiceClient(BaseClient):
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_paginator)
         """
 
     @overload
@@ -669,7 +669,7 @@ class ElasticsearchServiceClient(BaseClient):
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_paginator)
         """
 
     @overload
@@ -678,7 +678,7 @@ class ElasticsearchServiceClient(BaseClient):
     ) -> GetUpgradeHistoryPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_paginator)
         """
 
     @overload
@@ -687,7 +687,7 @@ class ElasticsearchServiceClient(BaseClient):
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_paginator)
         """
 
     @overload
@@ -696,5 +696,5 @@ class ElasticsearchServiceClient(BaseClient):
     ) -> ListElasticsearchVersionsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_es/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_es/client/#get_paginator)
         """
